#
# spec file for package python-python-rpm-spec
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-python-rpm-spec
Version:        0.14.1
Release:        1.1
Summary:        Python module for parsing RPM spec files
License:        MIT
Group:          Development/Libraries/Python
URL:            https://github.com/bkircher/python-rpm-spec
Source0:        https://files.pythonhosted.org/packages/source/p/python-rpm-spec/python-rpm-spec-%{version}.tar.gz
# PATCH-FIX-OPENSUSE avoid-DoS-on-carefully-crafted-spec-files.patch bsc#1215274
# this patch fixes an endless loop that could be triggered by carefully crafting
# a malicious RPM spec file that uses macro expansions, causing a denial-of-service
# PR to upstream code here: https://github.com/bkircher/python-rpm-spec/pull/62
Patch0:         avoid-DoS-on-carefully-crafted-spec-files.patch
BuildRequires:  %{python_module flit}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Conflicts:      python-pyrpm
BuildArch:      noarch
%python_subpackages

%description
python-rpm-spec is a Python module for parsing RPM spec files. RPMs are build
from a package's sources along with a spec file. The spec file controls how the
RPM is built. This module allows you to parse spec files and gives you simple
access to various bits of information that is contained in the spec file.

%prep
%setup -q -n python-rpm-spec-%{version}
%patch0 -p1

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest tests

%files %{python_files}
%doc CHANGELOG* README*
%license LICENSE*
%{python_sitelib}/python_rpm_spec-%{version}*-info
%{python_sitelib}/pyrpm

%changelog
* Wed Sep 13 2023 Martin Schreiner <martin.schreiner@suse.com>
- Replace the contents of avoid-DoS-on-carefully-crafted-spec-files.patch
  with a backwards-compatible patch, written by David Anes.
* Wed Sep 13 2023 Martin Schreiner <martin.schreiner@suse.com>
- Add avoid-DoS-on-carefully-crafted-spec-files.patch.
- Update to v0.14.1:
  - Changes from v0.14.1:
  - Fix replace_macro's behavior with user-defined conditional
    macros.
  - The parsing of package names was wrong when tab characters where
    used in %%package.
  - Implement parsing of spec files where sub-packages (%%package)
    have their own sources and patches defined. Previously, the
    parser would just fail with an error message like
    AttributeError: 'Package' object has no attribute
    'sources'. This is now fixed.
  - Use SemVer for versioning. git tags are now prefixed with v,
    e.g. v0.15.0 instead of 0.15.0.
  - Changes from v0.14:
  - Teach replace_macro how to deal with macros that are not wrapped
    in curly braces.
  - Add type annotations for tools like mypy, your IDE, and your
    brain.
  - Changes from v0.13:
  - Fix parsing of BuildRequires:, Requires:, Conflicts:,
    Obsoletes:, Provides: with comments at end of line..
  - Add CI for Python 3.11.
  - Changes from v0.12:
  - Fix %%description and %%changelog with multi-line strings.
  - Changes from v0.11:
  - Add type annotations for tools like mypy, your IDE, and your
    brain.
  - replace_macros() function now always expects a Spec instance as
    second argument. Does not make much sense without.
  - Add support for parsing %%description and %%changelog.
  - Add support for ExcludeArch and ExclusiveArch.
  - Add warnings_enabled knob to issue warnings of type UserWarning
    during spec file parsing.
* Tue Nov 17 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v0.10
  * Ignore spaces before ':' separator
  * Fix behavior of replace_macro function when macro is a tag
* Wed Aug  5 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.9
  * Ignore case when parsing directives
* Tue Mar  5 2019 John Vandenberg <jayvdb@gmail.com>
- Switch to using pythonhosted.org for sdist
- Update to v0.8
  * Enable parsing versions in `BuildRequires:` and `Requires:`
  * Add support for conditional macros, e.g. `%%{?test_macro:expression}`
  * Use flit for packaging
* Sun May 27 2018 toddrme2178@gmail.com
- Fix tests on Leap 42.3
- spec file cleanups
* Sun May 27 2018 toddrme2178@gmail.com
- spec file cleanups
* Sat May 26 2018 kbabioch@suse.com
- Initial packaging of version 0.7
